{ pkgs, ... }:

{
  imports = [
    # Import hardware configuration
    ./hardware-configuration.nix

    # Import modules
    ../../modules/system/default.nix
  ];

  settings = {
    display-manager = "cosmic-greeter";
    desktop-environments = {
      cosmic.enable = true;
      hyprland.enable = true;
      gnome.enable = false;
    };
    applications = {
      common.enable = true;
      steam.enable = true;
      thunar.enable = true;
    };
    services = {
      docker.enable = true;
      quickemu.enable = true;
      sunshine.enable = false;
      garbage-collection.enable = true;
    };
    hardware = {
      fprint.enable = true;
      printing.enable = true;
      bluetooth.enable = true;
      firewall.enable = true;
      locale.enable = true;
      nvidia.enable = false;
    };
  };

  nix.settings = {
    experimental-features = [ "nix-command" "flakes" ];

    substituters = [
      "https://nix-community.cachix.org"
      "https://cosmic.cachix.org/"
    ];

    trusted-public-keys = [
      "cosmic.cachix.org-1:Dya9IyXD4xdBehWjrkPv6rtxpmMdRel02smYzA85dPE="
    ];
  };

  # Enable host
  networking.hosts = {
    "127.0.0.1" = [ "adguard.timo.bmrs.nl" "git.timo.bmrs.nl" "auth.timo.bmrs.nl" "ldap.timo.bmrs.nl" "dozzle.timo.bmrs.nl" "home.timo.bmrs.nl" "immich.timo.bmrs.nl" "paperless.timo.bmrs.nl" "search.timo.bmrs.nl" ];
  };

  # Bootloader.
  boot.loader.efi.canTouchEfiVariables = true;
  boot.loader.grub = {
    enable = true;
    efiSupport = true;
    device = "nodev";
    configurationLimit = 32;
  };

  networking.hostName = "xv-laptop"; # Define your hostname.

  networking.firewall = {
    enable = true;
    allowedTCPPorts = [ 80 443 53 ];
    allowedUDPPorts = [ 80 443 53 ];
  };

  users.users.xeovalyte = {
    isNormalUser = true;
    description = "Timo Boomers";
    extraGroups = [ "networkmanager" "wheel" "dialout" ];
  };

  nix.settings.trusted-users = [ "root" "xeovalyte" ];

  # Prevent system freeze on high load
  services.earlyoom = {
    enable = true;
  };

  boot.kernelPackages = pkgs.linuxPackages_latest;

  system.stateVersion = "24.05";
}
