{ pkgs, lib, ... }:

{
  imports = [
    # Modules
    ../../modules/home/default.nix
  ];

  config = {
    home = {
      username = "xeovalyte";
      homeDirectory = "/home/xeovalyte";
    };

    host = "xv-laptop";

    settings = {
      hostname = "xv-laptop";

      applications.common.enable = true;
      applications.alacritty.enable = true;
      applications.devenv.enable = true;
      applications.firefox.enable = true;
      applications.git.enable = true;
      applications.helix.enable = true;
      applications.zsh.enable = true;
      applications.ssh.enable = true;
      applications.thunderbird.enable = true;
      applications.yazi.enable = true;
      applications.zellij.enable = true;

      services.nextcloud-sync.enable = true;

      theming.fonts.enable = true;
      theming.nix-colors.enable = false;
      theming.stylix.enable = true;

      desktop-environments.hyprland.enable = false;
    };

    home.packages = with pkgs; [
      # Desktop Applications
      kdenlive
      prismlauncher
      unstable.joplin-desktop
      unstable.prusa-slicer
      signal-desktop
      unstable.vesktop
      unstable.webcord
      blender
      unstable.freecad-wayland
      loupe
      unstable.rnote
      unstable.bottles

      # Office
      libreoffice

      # Image editing
      gimp
      inkscape
      unstable.obs-studio

      # Development
      unstable.drawio

      # Scripts
      (import ../../modules/scripts/save_image.nix { inherit pkgs; })
    ];

    # Enable home-manager
    programs.home-manager.enable = true;

    home.stateVersion = "24.05";
  };

  options = {
    settings.hostname = lib.mkOption {
      type = with lib.types; str;
      description = ''
        Define the host of the machine
      '';
    };
  };

}
